<?php

namespace App\Providers;

use Illuminate\Support\ServiceProvider;
use Spatie\SchemaOrg\ContactPage;
use Spatie\SchemaOrg\JobPosting;
use Spatie\SchemaOrg\Organization;
use Spatie\SchemaOrg\SearchResultsPage;
use Spatie\SchemaOrg\WebPage;

class SchemaOrgServiceProvider extends ServiceProvider
{
    // Public pages
    // https://schema.org/ContactPage
    // https://schema.org/WebPage
    public static function webPage($data)
    {
        $schema = new WebPage();
        $schema->abstract($data->title);

        return $schema;
    }

    // https://schema.org/ContactPage
    public static function contactPage($data)
    {
        $schema = new ContactPage();
        $schema->abstract($data->title);
        $schema->description($data->description);
        $schema->name($data->title);

        return $schema;
    }

    // https://schema.org/SearchResultsPage
    public static function searchResultsPage($data)
    {
        $schema = new SearchResultsPage();
        $schema->abstract($data->title);
        $schema->description($data->description);

        return $schema;
    }

    // https://schema.org/JobPosting
    public static function jobPosting($data)
    {
        $schema = new JobPosting();
        $schema->title($data->name);
        $schema->name($data->name);
        $schema->skills($data->skills_human_format);
        $schema->description(self::getDescriptionExcerpt(strip_tags($data->description)));
        $schema->baseSalary($data->salary);
        $schema->estimatedSalary($data->salary);
        $schema->datePosted($data->created_at->format('Y-m-d'));
        $schema->directApply('false');
        $schema->url(route('jobs.get', ['slug'=>$data->slug]));
        $schema->logo($data->company->logo);

        return $schema;
    }

    // https://schema.org/ProfilePage
    public static function profilePage()
    {
        // TODO: Prep it for JF
    }

    // https://schema.org/Organization
    public static function organization($data)
    {
        $schema = new Organization();
        $schema->logo($data->logo);
        $schema->name($data->name);
        $schema->description(self::getDescriptionExcerpt(strip_tags($data->description)));
        $schema->location($data->hq);
        $schema->url($data->website_url);

        return $schema;
    }

    public static function homepage()
    {
        $schema = new Organization();
        $schema->name(getSetting('site.name'));
        $schema->description(self::getDescriptionExcerpt(getSetting('site.description')));
        $schema->url(getSetting('site.app_url'));
        $schema->sameAs(self::getAvailableSocialNetworks());

        return $schema;
    }

    /**
     * Get available social networks set up (for advertising, not social-logins)
     * so it can be used on schema.org definitions.
     * @return array
     */
    public static function getAvailableSocialNetworks()
    {
        $data = array_values(array_filter([
            getSetting('social-media.facebook_url'),
            getSetting('social-media.twitter_url'),
            getSetting('social-media.instagram_url'),
            getSetting('social-media.whatsapp_url'),
            getSetting('social-media.tiktok_url'),
            getSetting('social-media.youtube_url'),
            getSetting('social-media.telegram_link'),
            getSetting('social-media.reddit_url'),
        ]));

        return json_encode($data);
    }

    /**
     * Generates truncated descriptions.
     * @param $description
     * @return string
     */
    public static function getDescriptionExcerpt($description)
    {
        $description = strip_tags($description);

        return strlen($description) > 250 ? $description.'...' : $description;
    }
}
